@@ -22,7 +22,7 @@
 # The Script was developed for the operating systems Solaris, Linux and MacOS.
 
 # The SDK name
-OO_SDK_NAME=libreoffice6.4_sdk
+OO_SDK_NAME=libreoffice7.3_sdk
 export OO_SDK_NAME
 
 # Installation directory of the Software Development Kit.
@@ -200,7 +200,7 @@ esac
 PATH=${OO_SDK_HOME}/bin:${OO_SDK_OUT}/${exampleout}/bin:${OO_SDK_URE_BIN_DIR}:${OFFICE_PROGRAM_PATH}:${PATH}
 
 # Set the classpath
-CLASSPATH=${OO_SDK_URE_JAVA_DIR}/juh.jar:${OO_SDK_URE_JAVA_DIR}/jurt.jar:${OO_SDK_URE_JAVA_DIR}/ridl.jar:${OO_SDK_URE_JAVA_DIR}/unoloader.jar:${OFFICE_HOME}/$sdk_lo_java_dir/unoil.jar:${CLASSPATH}
+CLASSPATH=${OO_SDK_URE_JAVA_DIR}/libreoffice.jar:${OO_SDK_URE_JAVA_DIR}/unoloader.jar:${CLASSPATH}
 export CLASSPATH
 
 
